==> thunderbird_66.0~b1.orig.tar.xz: thunderbird-66.0/browser/components/newtab/prerendered/locales/zh-TW/activity-stream-strings.js <==
// Note - this is a generated zh-TW file.
window.gActivityStreamStrings = {
  "newtab_page_title": "新分頁",
  "header_top_sites": "熱門網站",
  "header_highlights": "精選網站",
  "header_recommended_by": "{provider} 推薦",
  "context_menu_button_sr": "開啟 {title} 的右鍵選單",
  "section_context_menu_button_sr": "開啟段落內容選單",
  "type_label_visited": "造訪過的網站",
  "type_label_bookmarked": "已加入書籤",
  "type_label_recommended": "熱門",
  "type_label_pocket": "已儲存至 Pocket",
  "type_label_downloaded": "已下載",
  "menu_action_bookmark": "書籤",
  "menu_action_remove_bookmark": "移除書籤",
  "menu_action_open_new_window": "用新視窗開啟",
  "menu_action_open_private_window": "用新隱私視窗開啟",
  "menu_action_dismiss": "隱藏",
  "menu_action_delete": "從瀏覽紀錄刪除",
  "menu_action_pin": "釘選",
  "menu_action_unpin": "取消釘選",
  "confirm_history_delete_p1": "您確定要刪除此頁面的所有瀏覽紀錄？",
  "confirm_history_delete_notice_p2": "此動作無法復原。",
  "menu_action_save_to_pocket": "儲存至 Pocket",
  "menu_action_delete_pocket": "從 Pocket 刪除",
  "menu_action_archive_pocket": "在 Pocket 裡封存",
  "menu_action_show_file_mac_os": "顯示於 Finder",
  "menu_action_show_file_windows": "開啟所在資料夾",
  "menu_action_show_file_linux": "開啟所在資料夾",
  "menu_action_show_file_default": "顯示檔案",
  "menu_action_open_file": "開啟檔案",
  "menu_action_copy_download_link": "複製下載鏈結",
  "menu_action_go_to_download_page": "前往下載頁面",
  "menu_action_remove_download": "自下載記錄移除",
  "search_button": "搜尋",
  "search_header": "{search_engine_name} 搜尋",
  "search_web_placeholder": "搜尋 Web",
  "section_disclaimer_topstories": "依照您閱讀過的內容，向您推薦網路上最有趣的內容。本功能由 Pocket（Mozilla 的一員）提供。",
  "section_disclaimer_topstories_linktext": "了解運作原理。",
  "section_disclaimer_topstories_buttontext": "好的，知道了",
  "prefs_home_header": "Firefox 首頁內容",
  "prefs_home_description": "選擇要在您的 Firefox 首頁顯示哪些內容。",
  "prefs_content_discovery_header": "Firefox 首頁",
  "prefs_content_discovery_description": "Firefox Home 的內容探索功能可隨您上網，為您尋找高品質而與您有關的文章。",
  "prefs_content_discovery_button": "關閉內容探索功能",
  "prefs_section_rows_option": "{num} 行",
  "prefs_search_header": "網頁搜尋",
  "prefs_topsites_description": "最常造訪的網站",
  "prefs_topstories_description2": "網路上的各種超棒內容，為您量身打造",
  "prefs_topstories_options_sponsored_label": "贊助內容",
  "prefs_topstories_sponsored_learn_more": "了解更多",
  "prefs_highlights_description": "您儲存或造訪過的網站精選",
  "prefs_highlights_options_visited_label": "造訪過的頁面",
  "prefs_highlights_options_download_label": "最新下載",
  "prefs_highlights_options_pocket_label": "儲存至 Pocket 的頁面",
  "prefs_snippets_description": "來自 Mozilla 及 Firefox 的大小事",
  "settings_pane_button_label": "自訂您的新分頁頁面",
  "settings_pane_topsites_header": "熱門網站",
  "settings_pane_highlights_header": "精選網站",
  "settings_pane_highlights_options_bookmarks": "書籤",
  "settings_pane_snippets_header": "隻字片語",
  "edit_topsites_button_text": "編輯",
  "edit_topsites_edit_button": "編輯此網站",
  "topsites_form_add_header": "新增熱門網站",
  "topsites_form_edit_header": "編輯熱門網站",
  "topsites_form_title_label": "標題",
  "topsites_form_title_placeholder": "輸入標題",
  "topsites_form_url_label": "網址",
  "topsites_form_image_url_label": "自訂圖片網址",
  "topsites_form_url_placeholder": "輸入或貼上網址",
  "topsites_form_use_image_link": "使用自訂圖片…",
  "topsites_form_preview_button": "預覽",
  "topsites_form_add_button": "新增",
  "topsites_form_save_button": "儲存",
  "topsites_form_cancel_button": "取消",
  "topsites_form_url_validation": "請輸入有效的網址",
  "topsites_form_image_validation": "圖片載入失敗，請改用不同網址。",
  "pocket_read_more": "熱門主題:",
  "pocket_read_even_more": "檢視更多文章",
  "pocket_more_reccommendations": "更多推薦項目",
  "pocket_how_it_works": "原理是什麼",
  "pocket_cta_button": "取得 Pocket",
  "pocket_cta_text": "將您喜愛的故事儲存到 Pocket，閱讀一篇篇好文章。",
  "highlights_empty_state": "開始上網，我們就會把您在網路上發現的好文章、影片、剛加入書籤的頁面顯示於此。",
  "topstories_empty_state": "所有文章都讀完啦！晚點再來，{provider} 將提供更多推薦故事。等不及了？選擇熱門主題，看看 Web 上各式精采資訊。",
  "manual_migration_explanation2": "試試將其他瀏覽器的書籤、瀏覽記錄與密碼匯入 Firefox。",
  "manual_migration_cancel_button": "不要，謝謝",
  "manual_migration_import_button": "立即匯入",
  "error_fallback_default_info": "唉唷，載入內容時發生錯誤。",
  "error_fallback_default_refresh_suggestion": "請重新整理頁面再試一次。",
  "section_menu_action_remove_section": "移除段落",
  "section_menu_action_collapse_section": "摺疊段落",
  "section_menu_action_expand_section": "展開段落",
  "section_menu_action_manage_section": "管理段落",
  "section_menu_action_manage_webext": "管理擴充套件",
  "section_menu_action_add_topsite": "新增熱門網站",
  "section_menu_action_add_search_engine": "新增搜尋引擎",
  "section_menu_action_move_up": "上移",
  "section_menu_action_move_down": "下移",
  "section_menu_action_privacy_notice": "隱私權公告",
  "firstrun_title": "Firefox 隨身帶著走",
  "firstrun_content": "在您的任何裝置上取得書籤、瀏覽紀錄、密碼及其他設定。",
  "firstrun_learn_more_link": "了解 Firefox Accounts 的更多資訊",
  "firstrun_form_header": "輸入您的電子郵件地址",
  "firstrun_form_sub_header": "繼續前往 Firefox Sync",
  "firstrun_email_input_placeholder": "電子郵件",
  "firstrun_invalid_input": "必須輸入有效的電子郵件地址",
  "firstrun_extra_legal_links": "若繼續，代表您同意{terms}及{privacy}。",
  "firstrun_terms_of_service": "服務條款",
  "firstrun_privacy_notice": "隱私權公告",
  "firstrun_continue_to_login": "繼續",
  "firstrun_skip_login": "跳過這步",
  "context_menu_title": "開啟選單"
};

==> thunderbird_68.5.0.orig.tar.xz: thunderbird-68.5.0/browser/components/newtab/prerendered/locales/zh-TW/activity-stream-strings.js <==
// Note - this is a generated zh-TW file.
window.gActivityStreamStrings = {
  "newtab_page_title": "新分頁",
  "header_top_sites": "熱門網站",
  "header_highlights": "精選網站",
  "header_recommended_by": "{provider} 推薦",
  "context_menu_button_sr": "開啟 {title} 的右鍵選單",
  "section_context_menu_button_sr": "開啟段落內容選單",
  "type_label_visited": "造訪過的網站",
  "type_label_bookmarked": "已加入書籤",
  "type_label_recommended": "熱門",
  "type_label_pocket": "已儲存至 Pocket",
  "type_label_downloaded": "已下載",
  "menu_action_bookmark": "書籤",
  "menu_action_remove_bookmark": "移除書籤",
  "menu_action_open_new_window": "用新視窗開啟",
  "menu_action_open_private_window": "用新隱私視窗開啟",
  "menu_action_dismiss": "隱藏",
  "menu_action_delete": "從瀏覽紀錄刪除",
  "menu_action_pin": "釘選",
  "menu_action_unpin": "取消釘選",
  "confirm_history_delete_p1": "您確定要刪除此頁面的所有瀏覽紀錄？",
  "confirm_history_delete_notice_p2": "此動作無法復原。",
  "menu_action_save_to_pocket": "儲存至 Pocket",
  "menu_action_delete_pocket": "從 Pocket 刪除",
  "menu_action_archive_pocket": "在 Pocket 裡封存",
  "menu_action_show_file_mac_os": "顯示於 Finder",
  "menu_action_show_file_windows": "開啟所在資料夾",
  "menu_action_show_file_linux": "開啟所在資料夾",
  "menu_action_show_file_default": "顯示檔案",
  "menu_action_open_file": "開啟檔案",
  "menu_action_copy_download_link": "複製下載鏈結",
  "menu_action_go_to_download_page": "前往下載頁面",
  "menu_action_remove_download": "自下載記錄移除",
  "search_button": "搜尋",
  "search_header": "{search_engine_name} 搜尋",
  "search_web_placeholder": "搜尋 Web",
  "section_disclaimer_topstories": "依照您閱讀過的內容，向您推薦網路上最有趣的內容。本功能由 Pocket（Mozilla 的一員）提供。",
  "section_disclaimer_topstories_linktext": "了解運作原理。",
  "section_disclaimer_topstories_buttontext": "好的，知道了",
  "prefs_home_header": "Firefox 首頁內容",
  "prefs_home_description": "選擇要在您的 Firefox 首頁顯示哪些內容。",
  "prefs_content_discovery_description": "Firefox Home 的內容探索功能可隨您上網，為您尋找高品質而與您有關的文章。",
  "prefs_section_rows_option": "{num} 行",
  "prefs_search_header": "網頁搜尋",
  "prefs_topsites_description": "最常造訪的網站",
  "prefs_topstories_description2": "網路上的各種超棒內容，為您量身打造",
  "prefs_topstories_options_sponsored_label": "贊助內容",
  "prefs_topstories_sponsored_learn_more": "了解更多",
  "prefs_highlights_description": "您儲存或造訪過的網站精選",
  "prefs_highlights_options_visited_label": "造訪過的頁面",
  "prefs_highlights_options_download_label": "最新下載",
  "prefs_highlights_options_pocket_label": "儲存至 Pocket 的頁面",
  "prefs_snippets_description": "來自 Mozilla 及 Firefox 的大小事",
  "settings_pane_button_label": "自訂您的新分頁頁面",
  "settings_pane_topsites_header": "熱門網站",
  "settings_pane_highlights_header": "精選網站",
  "settings_pane_highlights_options_bookmarks": "書籤",
  "settings_pane_snippets_header": "隻字片語",
  "edit_topsites_button_text": "編輯",
  "edit_topsites_edit_button": "編輯此網站",
  "topsites_form_add_header": "新增熱門網站",
  "topsites_form_edit_header": "編輯熱門網站",
  "topsites_form_title_label": "標題",
  "topsites_form_title_placeholder": "輸入標題",
  "topsites_form_url_label": "網址",
  "topsites_form_image_url_label": "自訂圖片網址",
  "topsites_form_url_placeholder": "輸入或貼上網址",
  "topsites_form_use_image_link": "使用自訂圖片…",
  "topsites_form_preview_button": "預覽",
  "topsites_form_add_button": "新增",
  "topsites_form_save_button": "儲存",
  "topsites_form_cancel_button": "取消",
  "topsites_form_url_validation": "請輸入有效的網址",
  "topsites_form_image_validation": "圖片載入失敗，請改用不同網址。",
  "pocket_read_more": "熱門主題:",
  "pocket_read_even_more": "檢視更多文章",
  "pocket_more_reccommendations": "更多推薦項目",
  "pocket_how_it_works": "原理是什麼",
  "pocket_cta_button": "取得 Pocket",
  "pocket_cta_text": "將您喜愛的故事儲存到 Pocket，閱讀一篇篇好文章。",
  "highlights_empty_state": "開始上網，我們就會把您在網路上發現的好文章、影片、剛加入書籤的頁面顯示於此。",
  "topstories_empty_state": "所有文章都讀完啦！晚點再來，{provider} 將提供更多推薦故事。等不及了？選擇熱門主題，看看 Web 上各式精采資訊。",
  "error_fallback_default_info": "唉唷，載入內容時發生錯誤。",
  "error_fallback_default_refresh_suggestion": "請重新整理頁面再試一次。",
  "section_menu_action_remove_section": "移除段落",
  "section_menu_action_collapse_section": "摺疊段落",
  "section_menu_action_expand_section": "展開段落",
  "section_menu_action_manage_section": "管理段落",
  "section_menu_action_manage_webext": "管理擴充套件",
  "section_menu_action_add_topsite": "新增熱門網站",
  "section_menu_action_add_search_engine": "新增搜尋引擎",
  "section_menu_action_move_up": "上移",
  "section_menu_action_move_down": "下移",
  "section_menu_action_privacy_notice": "隱私權公告",
  "firstrun_title": "Firefox 隨身帶著走",
  "firstrun_content": "在您的各種裝置上同步書籤、瀏覽紀錄、登入資訊及其他設定。",
  "firstrun_learn_more_link": "了解 Firefox Accounts 的更多資訊",
  "firstrun_form_header": "輸入您的電子郵件地址",
  "firstrun_form_sub_header": "繼續前往 Firefox Sync",
  "firstrun_email_input_placeholder": "電子郵件",
  "firstrun_invalid_input": "必須輸入有效的電子郵件地址",
  "firstrun_extra_legal_links": "若繼續，代表您同意{terms}及{privacy}。",
  "firstrun_terms_of_service": "服務條款",
  "firstrun_privacy_notice": "隱私權公告",
  "firstrun_continue_to_login": "繼續",
  "firstrun_skip_login": "跳過這步",
  "context_menu_title": "開啟選單"
};
